Stoppers
========
.. automodule:: pykeen.stoppers

.. autoclass:: pykeen.stoppers.NopStopper
   :members:

.. autoclass:: pykeen.stoppers.EarlyStopper
   :members:

Base Classes
------------
.. autoclass:: pykeen.stoppers.Stopper
   :members:
